pub enum VerificationError {
SumcheckStartFailed,
SumcheckFailed,
FinalSumcheckFailed,
GKRClaimCheckFailed,
ChallengeCheckFailed,
ExpressionError,
TranscriptError,
InterpError(InterpError),
}Expand description
Errors to do with verifying a layer while working with a type implementing VerifierLayer.
Variants
SumcheckStartFailed
The sum of the first evaluations do not equal the claim
SumcheckFailed
The sum of the current rounds evaluations do not equal the previous round at a random point
FinalSumcheckFailed
The final rounds evaluations at r do not equal the oracle query
GKRClaimCheckFailed
The Oracle query does not match the final claim
ChallengeCheckFailed
The Challenges generated during sumcheck don’t match the claims in the given expression
ExpressionError
Error with underlying expression
TranscriptError
Error while reading the transcript proof.
InterpError(InterpError)
Interpolation Error.