pub enum LayerId {
Input(usize),
FiatShamirChallengeLayer(usize),
Layer(usize),
}Expand description
The location of a layer within the GKR circuit
Variants
Input(usize)
An Mle located in the input layer
FiatShamirChallengeLayer(usize)
A layer representing values sampled from the verifier via Fiat-Shamir
Layer(usize)
A layer between the output layer and input layers
Implementations
Sourceimpl LayerId
impl LayerId
Sourcepub fn next_input_layer_id() -> Self
pub fn next_input_layer_id() -> Self
Creates a new LayerId representing an input layer.
Sourcepub fn next_layer_id() -> Self
pub fn next_layer_id() -> Self
Creates a new LayerId representing a layer.
Sourcepub fn next_fiat_shamir_challenge_layer_id() -> Self
pub fn next_fiat_shamir_challenge_layer_id() -> Self
Creates a new LayerId representing a Fiat-Shamir challenge layer.
Sourcepub fn get_raw_input_layer_id(&self) -> usize
pub fn get_raw_input_layer_id(&self) -> usize
Returns the underlying usize if self is a variant of type Input, otherwise panics.
Sourcepub fn get_raw_layer_id(&self) -> usize
pub fn get_raw_layer_id(&self) -> usize
Returns the underlying usize if self is a variant of type Input, otherwise panics.